@@ -3,7 +3,8 @@ import json
 import os
 import unittest
 import types
-import responses # type: ignore
+import responses  # type: ignore
+import datetime
 
 import click.testing
 from click.testing import CliRunner
@@ -38,6 +39,8 @@ class CliTestCase(unittest.TestCase):
                       json={}, status=200)
         responses.add(responses.PATCH, "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions/{}/close".format(get_base_url(), self.organization, self.workspace, self.build_name, self.session_id),
                       json={}, status=200)
+        responses.add(responses.GET, "{}/intake/organizations/{}/workspaces/{}/builds/{}".format(get_base_url(), self.organization, self.workspace, self.build_name),
+                      json={'createdAt': "2020-01-02T03:45:56.123+00:00", 'id': 123}, status=200)
 
     def tearDown(self):
         clean_session_files()
